@@ -48,10 +48,11 @@ from textwrap import TextWrapper
 
 import re
 
-from ..enums import AppCommandOptionType, AppCommandType
+from ..enums import AppCommandOptionType, AppCommandType, ChannelType, Locale
 from .models import Choice
 from .transformers import annotation_to_parameter, CommandParameter, NoneType
 from .errors import AppCommandError, CheckFailure, CommandInvokeError, CommandSignatureMismatch, CommandAlreadyRegistered
+from .translator import TranslationContext, TranslationContextLocation, Translator, locale_str
 from ..message import Message
 from ..user import User
 from ..member import Member
@@ -76,6 +77,7 @@ __all__ = (
     'Command',
     'ContextMenu',
     'Group',
+    'Parameter',
     'context_menu',
     'command',
     'describe',
@@ -281,18 +283,21 @@ def _populate_descriptions(params: Dict[str, CommandParameter], descriptions: Di
             param.description = '…'
             continue
 
-        if not isinstance(description, str):
+        if not isinstance(description, (str, locale_str)):
             raise TypeError('description must be a string')
 
-        param.description = _shorten(description)
+        if isinstance(description, str):
+            param.description = _shorten(description)
+        else:
+            param.description = description
 
     if descriptions:
         first = next(iter(descriptions))
         raise TypeError(f'unknown parameter given: {first}')
 
 
-def _populate_renames(params: Dict[str, CommandParameter], renames: Dict[str, str]) -> None:
-    rename_map: Dict[str, str] = {}
+def _populate_renames(params: Dict[str, CommandParameter], renames: Dict[str, Union[str, locale_str]]) -> None:
+    rename_map: Dict[str, Union[str, locale_str]] = {}
 
     # original name to renamed name
 
@@ -306,7 +311,11 @@ def _populate_renames(params: Dict[str, CommandParameter], renames: Dict[str, st
         if name in rename_map:
             raise ValueError(f'{new_name} is already used')
 
-        new_name = validate_name(new_name)
+        if isinstance(new_name, str):
+            new_name = validate_name(new_name)
+        else:
+            validate_name(new_name.message)
+
         rename_map[name] = new_name
         params[name]._rename = new_name
 
@@ -449,6 +458,104 @@ def _get_context_menu_parameter(func: ContextMenuCallback) -> Tuple[str, Any, Ap
     return (parameter.name, resolved, type)
 
 
+class Parameter:
+    """A class that contains the parameter information of a :class:`Command` callback.
+
+    .. versionadded:: 2.0
+
+    Attributes
+    -----------
+    name: :class:`str`
+        The name of the parameter. This is the Python identifier for the parameter.
+    display_name: :class:`str`
+        The displayed name of the parameter on Discord.
+    description: :class:`str`
+        The description of the parameter.
+    autocomplete: :class:`bool`
+        Whether the parameter has an autocomplete handler.
+    locale_name: Optional[:class:`locale_str`]
+        The display name's locale string, if available.
+    locale_description: Optional[:class:`locale_str`]
+        The description's locale string, if available.
+    required: :class:`bool`
+        Whether the parameter is required
+    choices: List[:class:`~discord.app_commands.Choice`]
+        A list of choices this parameter takes, if any.
+    type: :class:`~discord.AppCommandOptionType`
+        The underlying type of this parameter.
+    channel_types: List[:class:`~discord.ChannelType`]
+        The channel types that are allowed for this parameter.
+    min_value: Optional[Union[:class:`int`, :class:`float`]]
+        The minimum supported value for this parameter.
+    max_value: Optional[Union[:class:`int`, :class:`float`]]
+        The maximum supported value for this parameter.
+    default: Any
+        The default value of the parameter, if given.
+        If not given then this is :data:`~discord.utils.MISSING`.
+    """
+
+    def __init__(self, parent: CommandParameter) -> None:
+        self.__parent: CommandParameter = parent
+
+    @property
+    def name(self) -> str:
+        return self.__parent.name
+
+    @property
+    def display_name(self) -> str:
+        return self.__parent.display_name
+
+    @property
+    def description(self) -> str:
+        return str(self.__parent.description)
+
+    @property
+    def locale_name(self) -> Optional[locale_str]:
+        if isinstance(self.__parent._rename, locale_str):
+            return self.__parent._rename
+        return None
+
+    @property
+    def locale_description(self) -> Optional[locale_str]:
+        if isinstance(self.__parent.description, locale_str):
+            return self.__parent.description
+        return None
+
+    @property
+    def autocomplete(self) -> bool:
+        return self.__parent.autocomplete is not None
+
+    @property
+    def default(self) -> Any:
+        return self.__parent.default
+
+    @property
+    def type(self) -> AppCommandOptionType:
+        return self.__parent.type
+
+    @property
+    def choices(self) -> List[Choice[Union[int, float, str]]]:
+        choices = self.__parent.choices
+        if choices is MISSING:
+            return []
+        return choices.copy()
+
+    @property
+    def channel_types(self) -> List[ChannelType]:
+        channel_types = self.__parent.channel_types
+        if channel_types is MISSING:
+            return []
+        return channel_types.copy()
+
+    @property
+    def min_value(self) -> Optional[Union[int, float]]:
+        return self.__parent.min_value
+
+    @property
+    def max_value(self) -> Optional[Union[int, float]]:
+        return self.__parent.max_value
+
+
 class Command(Generic[GroupT, P, T]):
     """A class that implements an application command.
 
@@ -461,6 +568,32 @@ class Command(Generic[GroupT, P, T]):
 
     .. versionadded:: 2.0
 
+    Parameters
+    -----------
+    name: Union[:class:`str`, :class:`locale_str`]
+        The name of the application command.
+    description: Union[:class:`str`, :class:`locale_str`]
+        The description of the application command. This shows up in the UI to describe
+        the application command.
+    callback: :ref:`coroutine <coroutine>`
+        The coroutine that is executed when the command is called.
+    auto_locale_strings: :class:`bool`
+        If this is set to ``True``, then all translatable strings will implicitly
+        be wrapped into :class:`locale_str` rather than :class:`str`. This could
+        avoid some repetition and be more ergonomic for certain defaults such
+        as default command names, command descriptions, and parameter names.
+        Defaults to ``True``.
+    nsfw: :class:`bool`
+        Whether the command is NSFW and should only work in NSFW channels.
+        Defaults to ``False``.
+
+        Due to a Discord limitation, this does not work on subcommands.
+    parent: Optional[:class:`Group`]
+        The parent application command. ``None`` if there isn't one.
+    extras: :class:`dict`
+        A dictionary that can be used to store extraneous data.
+        The library will not touch any values or keys within this dictionary.
+
     Attributes
     ------------
     name: :class:`str`
@@ -483,12 +616,10 @@ class Command(Generic[GroupT, P, T]):
         Due to a Discord limitation, this does not work on subcommands.
     guild_only: :class:`bool`
         Whether the command should only be usable in guild contexts.
-        Defaults to ``False``.
 
         Due to a Discord limitation, this does not work on subcommands.
     nsfw: :class:`bool`
         Whether the command is NSFW and should only work in NSFW channels.
-        Defaults to ``False``.
 
         Due to a Discord limitation, this does not work on subcommands.
     parent: Optional[:class:`Group`]
@@ -501,16 +632,23 @@ class Command(Generic[GroupT, P, T]):
     def __init__(
         self,
         *,
-        name: str,
-        description: str,
+        name: Union[str, locale_str],
+        description: Union[str, locale_str],
         callback: CommandCallback[GroupT, P, T],
         nsfw: bool = False,
         parent: Optional[Group] = None,
         guild_ids: Optional[List[int]] = None,
+        auto_locale_strings: bool = True,
         extras: Dict[Any, Any] = MISSING,
     ):
+        name, locale = (name.message, name) if isinstance(name, locale_str) else (name, None)
         self.name: str = validate_name(name)
+        self._locale_name: Optional[locale_str] = locale
+        description, locale = (
+            (description.message, description) if isinstance(description, locale_str) else (description, None)
+        )
         self.description: str = description
+        self._locale_description: Optional[locale_str] = locale
         self._attr: Optional[str] = None
         self._callback: CommandCallback[GroupT, P, T] = callback
         self.parent: Optional[Group] = parent
@@ -540,6 +678,18 @@ class Command(Generic[GroupT, P, T]):
         if self._guild_ids is not None and self.parent is not None:
             raise ValueError('child commands cannot have default guilds set, consider setting them in the parent instead')
 
+        if auto_locale_strings:
+            self._convert_to_locale_strings()
+
+    def _convert_to_locale_strings(self) -> None:
+        if self._locale_name is None:
+            self._locale_name = locale_str(self.name)
+        if self._locale_description is None:
+            self._locale_description = locale_str(self.description)
+
+        for param in self._params.values():
+            param._convert_to_locale_strings()
+
     def __set_name__(self, owner: Type[Any], name: str) -> None:
         self._attr = name
 
@@ -561,9 +711,11 @@ class Command(Generic[GroupT, P, T]):
         cls = self.__class__
         copy = cls.__new__(cls)
         copy.name = self.name
+        copy._locale_name = self._locale_name
         copy._guild_ids = self._guild_ids
         copy.checks = self.checks
         copy.description = self.description
+        copy._locale_description = self._locale_description
         copy.default_permissions = self.default_permissions
         copy.guild_only = self.guild_only
         copy.nsfw = self.nsfw
@@ -581,6 +733,33 @@ class Command(Generic[GroupT, P, T]):
 
         return copy
 
+    async def get_translated_payload(self, translator: Translator) -> Dict[str, Any]:
+        base = self.to_dict()
+        name_localizations: Dict[str, str] = {}
+        description_localizations: Dict[str, str] = {}
+
+        # Prevent creating these objects in a heavy loop
+        name_context = TranslationContext(location=TranslationContextLocation.command_name, data=self)
+        description_context = TranslationContext(location=TranslationContextLocation.command_description, data=self)
+
+        for locale in Locale:
+            if self._locale_name:
+                translation = await translator._checked_translate(self._locale_name, locale, name_context)
+                if translation is not None:
+                    name_localizations[locale.value] = translation
+
+            if self._locale_description:
+                translation = await translator._checked_translate(self._locale_description, locale, description_context)
+                if translation is not None:
+                    description_localizations[locale.value] = translation
+
+        base['name_localizations'] = name_localizations
+        base['description_localizations'] = description_localizations
+        base['options'] = [
+            await param.get_translated_payload(translator, Parameter(param)) for param in self._params.values()
+        ]
+        return base
+
     def to_dict(self) -> Dict[str, Any]:
         # If we have a parent then our type is a subcommand
         # Otherwise, the type falls back to the specific command type (e.g. slash command or context menu)
@@ -732,6 +911,28 @@ class Command(Generic[GroupT, P, T]):
     def _get_internal_command(self, name: str) -> Optional[Union[Command, Group]]:
         return None
 
+    def get_parameter(self, name: str) -> Optional[Parameter]:
+        """Retrieves a parameter by its name.
+
+        The name must be the Python identifier rather than the renamed
+        one for display on Discord.
+
+        Parameters
+        -----------
+        name: :class:`str`
+            The parameter name in the callback function.
+
+        Returns
+        --------
+        Optional[:class:`Parameter`]
+            The parameter or ``None`` if not found.
+        """
+
+        parent = self._params.get(name)
+        if parent is not None:
+            return Parameter(parent)
+        return None
+
     @property
     def root_parent(self) -> Optional[Group]:
         """Optional[:class:`Group`]: The root parent of this command."""
@@ -926,6 +1127,28 @@ class ContextMenu:
 
     .. versionadded:: 2.0
 
+    Parameters
+    -----------
+    name: Union[:class:`str`, :class:`locale_str`]
+        The name of the context menu.
+    callback: :ref:`coroutine <coroutine>`
+        The coroutine that is executed when the command is called.
+    type: :class:`.AppCommandType`
+        The type of context menu application command. By default, this is inferred
+        by the parameter of the callback.
+    auto_locale_strings: :class:`bool`
+        If this is set to ``True``, then all translatable strings will implicitly
+        be wrapped into :class:`locale_str` rather than :class:`str`. This could
+        avoid some repetition and be more ergonomic for certain defaults such
+        as default command names, command descriptions, and parameter names.
+        Defaults to ``True``.
+    nsfw: :class:`bool`
+        Whether the command is NSFW and should only work in NSFW channels.
+        Defaults to ``False``.
+    extras: :class:`dict`
+        A dictionary that can be used to store extraneous data.
+        The library will not touch any values or keys within this dictionary.
+
     Attributes
     ------------
     name: :class:`str`
@@ -958,14 +1181,17 @@ class ContextMenu:
     def __init__(
         self,
         *,
-        name: str,
+        name: Union[str, locale_str],
         callback: ContextMenuCallback,
         type: AppCommandType = MISSING,
         nsfw: bool = False,
         guild_ids: Optional[List[int]] = None,
+        auto_locale_strings: bool = True,
         extras: Dict[Any, Any] = MISSING,
     ):
+        name, locale = (name.message, name) if isinstance(name, locale_str) else (name, None)
         self.name: str = validate_context_menu_name(name)
+        self._locale_name: Optional[locale_str] = locale
         self._callback: ContextMenuCallback = callback
         (param, annotation, actual_type) = _get_context_menu_parameter(callback)
         if type is MISSING:
@@ -988,6 +1214,10 @@ class ContextMenu:
         self.checks: List[Check] = getattr(callback, '__discord_app_commands_checks__', [])
         self.extras: Dict[Any, Any] = extras or {}
 
+        if auto_locale_strings:
+            if self._locale_name is None:
+                self._locale_name = locale_str(self.name)
+
     @property
     def callback(self) -> ContextMenuCallback:
         """:ref:`coroutine <coroutine>`: The coroutine that is executed when the context menu is called."""
@@ -998,6 +1228,19 @@ class ContextMenu:
         """:class:`str`: Returns the fully qualified command name."""
         return self.name
 
+    async def get_translated_payload(self, translator: Translator) -> Dict[str, Any]:
+        base = self.to_dict()
+        context = TranslationContext(location=TranslationContextLocation.command_name, data=self)
+        if self._locale_name:
+            name_localizations: Dict[str, str] = {}
+            for locale in Locale:
+                translation = await translator._checked_translate(self._locale_name, locale, context)
+                if translation is not None:
+                    name_localizations[locale.value] = translation
+
+            base['name_localizations'] = name_localizations
+        return base
+
     def to_dict(self) -> Dict[str, Any]:
         return {
             'name': self.name,
@@ -1103,15 +1346,21 @@ class Group:
 
     .. versionadded:: 2.0
 
-    Attributes
-    ------------
-    name: :class:`str`
+    Parameters
+    -----------
+    name: Union[:class:`str`, :class:`locale_str`]
         The name of the group. If not given, it defaults to a lower-case
         kebab-case version of the class name.
-    description: :class:`str`
+    description: Union[:class:`str`, :class:`locale_str`]
         The description of the group. This shows up in the UI to describe
         the group. If not given, it defaults to the docstring of the
         class shortened to 100 characters.
+    auto_locale_strings: :class:`bool`
+        If this is set to ``True``, then all translatable strings will implicitly
+        be wrapped into :class:`locale_str` rather than :class:`str`. This could
+        avoid some repetition and be more ergonomic for certain defaults such
+        as default command names, command descriptions, and parameter names.
+        Defaults to ``True``.
     default_permissions: Optional[:class:`~discord.Permissions`]
         The default permissions that can execute this group on Discord. Note
         that server administrators can override this value in the client.
@@ -1128,6 +1377,34 @@ class Group:
         Whether the command is NSFW and should only work in NSFW channels.
         Defaults to ``False``.
 
+        Due to a Discord limitation, this does not work on subcommands.
+    parent: Optional[:class:`Group`]
+        The parent application command. ``None`` if there isn't one.
+    extras: :class:`dict`
+        A dictionary that can be used to store extraneous data.
+        The library will not touch any values or keys within this dictionary.
+
+    Attributes
+    ------------
+    name: :class:`str`
+        The name of the group.
+    description: :class:`str`
+        The description of the group. This shows up in the UI to describe
+        the group.
+    default_permissions: Optional[:class:`~discord.Permissions`]
+        The default permissions that can execute this group on Discord. Note
+        that server administrators can override this value in the client.
+        Setting an empty permissions field will disallow anyone except server
+        administrators from using the command in a guild.
+
+        Due to a Discord limitation, this does not work on subcommands.
+    guild_only: :class:`bool`
+        Whether the group should only be usable in guild contexts.
+
+        Due to a Discord limitation, this does not work on subcommands.
+    nsfw: :class:`bool`
+        Whether the command is NSFW and should only work in NSFW channels.
+
         Due to a Discord limitation, this does not work on subcommands.
     parent: Optional[:class:`Group`]
         The parent group. ``None`` if there isn't one.
@@ -1140,6 +1417,8 @@ class Group:
     __discord_app_commands_skip_init_binding__: bool = False
     __discord_app_commands_group_name__: str = MISSING
     __discord_app_commands_group_description__: str = MISSING
+    __discord_app_commands_group_locale_name__: Optional[locale_str] = None
+    __discord_app_commands_group_locale_description__: Optional[locale_str] = None
     __discord_app_commands_group_nsfw__: bool = False
     __discord_app_commands_guild_only__: bool = MISSING
     __discord_app_commands_default_permissions__: Optional[Permissions] = MISSING
@@ -1151,8 +1430,8 @@ class Group:
     def __init_subclass__(
         cls,
         *,
-        name: str = MISSING,
-        description: str = MISSING,
+        name: Union[str, locale_str] = MISSING,
+        description: Union[str, locale_str] = MISSING,
         guild_only: bool = MISSING,
         nsfw: bool = False,
         default_permissions: Optional[Permissions] = MISSING,
@@ -1175,16 +1454,22 @@ class Group:
 
         if name is MISSING:
             cls.__discord_app_commands_group_name__ = validate_name(_to_kebab_case(cls.__name__))
-        else:
+        elif isinstance(name, str):
             cls.__discord_app_commands_group_name__ = validate_name(name)
+        else:
+            cls.__discord_app_commands_group_name__ = validate_name(name.message)
+            cls.__discord_app_commands_group_locale_name__ = name
 
         if description is MISSING:
             if cls.__doc__ is None:
                 cls.__discord_app_commands_group_description__ = '…'
             else:
                 cls.__discord_app_commands_group_description__ = _shorten(cls.__doc__)
-        else:
+        elif isinstance(description, str):
             cls.__discord_app_commands_group_description__ = description
+        else:
+            cls.__discord_app_commands_group_description__ = description.message
+            cls.__discord_app_commands_group_locale_description__ = description
 
         if guild_only is not MISSING:
             cls.__discord_app_commands_guild_only__ = guild_only
@@ -1199,18 +1484,39 @@ class Group:
     def __init__(
         self,
         *,
-        name: str = MISSING,
-        description: str = MISSING,
+        name: Union[str, locale_str] = MISSING,
+        description: Union[str, locale_str] = MISSING,
         parent: Optional[Group] = None,
         guild_ids: Optional[List[int]] = None,
         guild_only: bool = MISSING,
         nsfw: bool = MISSING,
+        auto_locale_strings: bool = True,
         default_permissions: Optional[Permissions] = MISSING,
         extras: Dict[Any, Any] = MISSING,
     ):
         cls = self.__class__
-        self.name: str = validate_name(name) if name is not MISSING else cls.__discord_app_commands_group_name__
-        self.description: str = description or cls.__discord_app_commands_group_description__
+
+        if name is MISSING:
+            name, locale = cls.__discord_app_commands_group_name__, cls.__discord_app_commands_group_locale_name__
+        elif isinstance(name, str):
+            name, locale = validate_name(name), None
+        else:
+            name, locale = validate_name(name.message), name
+        self.name: str = name
+        self._locale_name: Optional[locale_str] = locale
+
+        if description is MISSING:
+            description, locale = (
+                cls.__discord_app_commands_group_description__,
+                cls.__discord_app_commands_group_locale_description__,
+            )
+        elif isinstance(description, str):
+            description, locale = description, None
+        else:
+            description, locale = description.message, description
+        self.description: str = description
+        self._locale_description: Optional[locale_str] = locale
+
         self._attr: Optional[str] = None
         self._owner_cls: Optional[Type[Any]] = None
         self._guild_ids: Optional[List[int]] = guild_ids or getattr(cls, '__discord_app_commands_default_guilds__', None)
@@ -1273,6 +1579,17 @@ class Group:
                 raise ValueError('groups can only be nested at most one level')
             parent.add_command(self)
 
+        if auto_locale_strings:
+            self._convert_to_locale_strings()
+
+    def _convert_to_locale_strings(self) -> None:
+        if self._locale_name is None:
+            self._locale_name = locale_str(self.name)
+        if self._locale_description is None:
+            self._locale_description = locale_str(self.description)
+
+        # I don't know if propagating to the children is the right behaviour here.
+
     def __set_name__(self, owner: Type[Any], name: str) -> None:
         self._attr = name
         self.module = owner.__module__
@@ -1291,8 +1608,10 @@ class Group:
         cls = self.__class__
         copy = cls.__new__(cls)
         copy.name = self.name
+        copy._locale_name = self._locale_name
         copy._guild_ids = self._guild_ids
         copy.description = self.description
+        copy._locale_description = self._locale_description
         copy.parent = parent
         copy.module = self.module
         copy.default_permissions = self.default_permissions
@@ -1321,6 +1640,30 @@ class Group:
 
         return copy
 
+    async def get_translated_payload(self, translator: Translator) -> Dict[str, Any]:
+        base = self.to_dict()
+        name_localizations: Dict[str, str] = {}
+        description_localizations: Dict[str, str] = {}
+
+        # Prevent creating these objects in a heavy loop
+        name_context = TranslationContext(location=TranslationContextLocation.group_name, data=self)
+        description_context = TranslationContext(location=TranslationContextLocation.group_description, data=self)
+        for locale in Locale:
+            if self._locale_name:
+                translation = await translator._checked_translate(self._locale_name, locale, name_context)
+                if translation is not None:
+                    name_localizations[locale.value] = translation
+
+            if self._locale_description:
+                translation = await translator._checked_translate(self._locale_description, locale, description_context)
+                if translation is not None:
+                    description_localizations[locale.value] = translation
+
+        base['name_localizations'] = name_localizations
+        base['description_localizations'] = description_localizations
+        base['options'] = [await child.get_translated_payload(translator) for child in self._children.values()]
+        return base
+
     def to_dict(self) -> Dict[str, Any]:
         # If this has a parent command then it's part of a subcommand group
         # Otherwise, it's just a regular command
@@ -1535,24 +1878,31 @@ class Group:
     def command(
         self,
         *,
-        name: str = MISSING,
-        description: str = MISSING,
+        name: Union[str, locale_str] = MISSING,
+        description: Union[str, locale_str] = MISSING,
         nsfw: bool = False,
+        auto_locale_strings: bool = True,
         extras: Dict[Any, Any] = MISSING,
     ) -> Callable[[CommandCallback[GroupT, P, T]], Command[GroupT, P, T]]:
         """Creates an application command under this group.
 
         Parameters
         ------------
-        name: :class:`str`
+        name: Union[:class:`str`, :class:`locale_str`]
             The name of the application command. If not given, it defaults to a lower-case
             version of the callback name.
-        description: :class:`str`
+        description: Union[:class:`str`, :class:`locale_str`]
             The description of the application command. This shows up in the UI to describe
             the application command. If not given, it defaults to the first line of the docstring
             of the callback shortened to 100 characters.
         nsfw: :class:`bool`
             Whether the command is NSFW and should only work in NSFW channels. Defaults to ``False``.
+        auto_locale_strings: :class:`bool`
+            If this is set to ``True``, then all translatable strings will implicitly
+            be wrapped into :class:`locale_str` rather than :class:`str`. This could
+            avoid some repetition and be more ergonomic for certain defaults such
+            as default command names, command descriptions, and parameter names.
+            Defaults to ``True``.
         extras: :class:`dict`
             A dictionary that can be used to store extraneous data.
             The library will not touch any values or keys within this dictionary.
@@ -1576,6 +1926,7 @@ class Group:
                 callback=func,
                 nsfw=nsfw,
                 parent=self,
+                auto_locale_strings=auto_locale_strings,
                 extras=extras,
             )
             self.add_command(command)
@@ -1586,9 +1937,10 @@ class Group:
 
 def command(
     *,
-    name: str = MISSING,
-    description: str = MISSING,
+    name: Union[str, locale_str] = MISSING,
+    description: Union[str, locale_str] = MISSING,
     nsfw: bool = False,
+    auto_locale_strings: bool = True,
     extras: Dict[Any, Any] = MISSING,
 ) -> Callable[[CommandCallback[GroupT, P, T]], Command[GroupT, P, T]]:
     """Creates an application command from a regular function.
@@ -1606,6 +1958,12 @@ def command(
         Whether the command is NSFW and should only work in NSFW channels. Defaults to ``False``.
 
         Due to a Discord limitation, this does not work on subcommands.
+    auto_locale_strings: :class:`bool`
+        If this is set to ``True``, then all translatable strings will implicitly
+        be wrapped into :class:`locale_str` rather than :class:`str`. This could
+        avoid some repetition and be more ergonomic for certain defaults such
+        as default command names, command descriptions, and parameter names.
+        Defaults to ``True``.
     extras: :class:`dict`
         A dictionary that can be used to store extraneous data.
         The library will not touch any values or keys within this dictionary.
@@ -1629,6 +1987,7 @@ def command(
             callback=func,
             parent=None,
             nsfw=nsfw,
+            auto_locale_strings=auto_locale_strings,
             extras=extras,
         )
 
@@ -1637,8 +1996,9 @@ def command(
 
 def context_menu(
     *,
-    name: str = MISSING,
+    name: Union[str, locale_str] = MISSING,
     nsfw: bool = False,
+    auto_locale_strings: bool = True,
     extras: Dict[Any, Any] = MISSING,
 ) -> Callable[[ContextMenuCallback], ContextMenu]:
     """Creates an application command context menu from a regular function.
@@ -1662,7 +2022,7 @@ def context_menu(
 
     Parameters
     ------------
-    name: :class:`str`
+    name: Union[:class:`str`, :class:`locale_str`]
         The name of the context menu command. If not given, it defaults to a title-case
         version of the callback name. Note that unlike regular slash commands this can
         have spaces and upper case characters in the name.
@@ -1670,6 +2030,12 @@ def context_menu(
         Whether the command is NSFW and should only work in NSFW channels. Defaults to ``False``.
 
         Due to a Discord limitation, this does not work on subcommands.
+    auto_locale_strings: :class:`bool`
+        If this is set to ``True``, then all translatable strings will implicitly
+        be wrapped into :class:`locale_str` rather than :class:`str`. This could
+        avoid some repetition and be more ergonomic for certain defaults such
+        as default command names, command descriptions, and parameter names.
+        Defaults to ``True``.
     extras: :class:`dict`
         A dictionary that can be used to store extraneous data.
         The library will not touch any values or keys within this dictionary.
@@ -1680,12 +2046,18 @@ def context_menu(
             raise TypeError('context menu function must be a coroutine function')
 
         actual_name = func.__name__.title() if name is MISSING else name
-        return ContextMenu(name=actual_name, nsfw=nsfw, callback=func, extras=extras)
+        return ContextMenu(
+            name=actual_name,
+            nsfw=nsfw,
+            callback=func,
+            auto_locale_strings=auto_locale_strings,
+            extras=extras,
+        )
 
     return decorator
 
 
-def describe(**parameters: str) -> Callable[[T], T]:
+def describe(**parameters: Union[str, locale_str]) -> Callable[[T], T]:
     r"""Describes the given parameters by their name using the key of the keyword argument
     as the name.
 
@@ -1700,7 +2072,7 @@ def describe(**parameters: str) -> Callable[[T], T]:
 
     Parameters
     -----------
-    \*\*parameters
+    \*\*parameters: Union[:class:`str`, :class:`locale_str`]
         The description of the parameters.
 
     Raises
@@ -1723,7 +2095,7 @@ def describe(**parameters: str) -> Callable[[T], T]:
     return decorator
 
 
-def rename(**parameters: str) -> Callable[[T], T]:
+def rename(**parameters: Union[str, locale_str]) -> Callable[[T], T]:
     r"""Renames the given parameters by their name using the key of the keyword argument
     as the name.
 
@@ -1741,7 +2113,7 @@ def rename(**parameters: str) -> Callable[[T], T]:
 
     Parameters
     -----------
-    \*\*parameters
+    \*\*parameters: Union[:class:`str`, :class:`locale_str`]
         The name of the parameters.
 
     Raises
