@@ -26,11 +26,14 @@ from __future__ import annotations
 from datetime import datetime
 
 from .errors import MissingApplicationID
+from .translator import TranslationContextLocation, Translator, TranslationContext, locale_str
 from ..permissions import Permissions
-from ..enums import AppCommandOptionType, AppCommandType, AppCommandPermissionType, ChannelType, try_enum
+from ..enums import AppCommandOptionType, AppCommandType, AppCommandPermissionType, ChannelType, Locale, try_enum
 from ..mixins import Hashable
 from ..utils import _get_as_snowflake, parse_time, snowflake_time, MISSING
 from ..object import Object
+from ..role import Role
+from ..member import Member
 
 from typing import Any, Dict, Generic, List, TYPE_CHECKING, Optional, TypeVar, Union
 
@@ -56,7 +59,6 @@ def is_app_command_argument_type(value: int) -> bool:
 if TYPE_CHECKING:
     from ..types.command import (
         ApplicationCommand as ApplicationCommandPayload,
-        ApplicationCommandOptionChoice,
         ApplicationCommandOption,
         ApplicationCommandPermissions,
         GuildApplicationCommandPermissions,
@@ -75,9 +77,7 @@ if TYPE_CHECKING:
     from ..guild import GuildChannel, Guild
     from ..channel import TextChannel
     from ..threads import Thread
-    from ..role import Role
     from ..user import User
-    from ..member import Member
 
     ApplicationCommandParent = Union['AppCommand', 'AppCommandGroup']
 
@@ -107,6 +107,10 @@ class AllChannels:
         return f'<AllChannels guild={self.guild}>'
 
 
+def _to_locale_dict(data: Dict[str, str]) -> Dict[Locale, str]:
+    return {try_enum(Locale, key): value for key, value in data.items()}
+
+
 class AppCommand(Hashable):
     """Represents an application command.
 
@@ -145,6 +149,10 @@ class AppCommand(Hashable):
         The application command's name.
     description: :class:`str`
         The application command's description.
+    name_localizations: Dict[:class:`~discord.Locale`, :class:`str`]
+        The localised names of the application command. Used for display purposes.
+    description_localizations: Dict[:class:`~discord.Locale`, :class:`str`]
+        The localised descriptions of the application command. Used for display purposes.
     options: List[Union[:class:`Argument`, :class:`AppCommandGroup`]]
         A list of options.
     default_member_permissions: Optional[:class:`~discord.Permissions`]
@@ -164,6 +172,8 @@ class AppCommand(Hashable):
         'application_id',
         'name',
         'description',
+        'name_localizations',
+        'description_localizations',
         'guild_id',
         'options',
         'default_member_permissions',
@@ -200,6 +210,8 @@ class AppCommand(Hashable):
 
         self.dm_permission: bool = dm_permission
         self.nsfw: bool = data.get('nsfw', False)
+        self.name_localizations: Dict[Locale, str] = _to_locale_dict(data.get('name_localizations') or {})
+        self.description_localizations: Dict[Locale, str] = _to_locale_dict(data.get('description_localizations') or {})
 
     def to_dict(self) -> ApplicationCommandPayload:
         return {
@@ -208,6 +220,8 @@ class AppCommand(Hashable):
             'application_id': self.application_id,
             'name': self.name,
             'description': self.description,
+            'name_localizations': {str(k): v for k, v in self.name_localizations.items()},
+            'description_localizations': {str(k): v for k, v in self.description_localizations.items()},
             'options': [opt.to_dict() for opt in self.options],
         }  # type: ignore # Type checker does not understand this literal.
 
@@ -407,17 +421,22 @@ class Choice(Generic[ChoiceT]):
 
     Parameters
     -----------
-    name: :class:`str`
+    name: Union[:class:`str`, :class:`locale_str`]
         The name of the choice. Used for display purposes.
+    name_localizations: Dict[:class:`~discord.Locale`, :class:`str`]
+        The localised names of the choice. Used for display purposes.
     value: Union[:class:`int`, :class:`str`, :class:`float`]
         The value of the choice.
     """
 
-    __slots__ = ('name', 'value')
+    __slots__ = ('name', 'value', '_locale_name', 'name_localizations')
 
-    def __init__(self, *, name: str, value: ChoiceT):
+    def __init__(self, *, name: Union[str, locale_str], value: ChoiceT, name_localizations: Dict[Locale, str] = MISSING):
+        name, locale = (name.message, name) if isinstance(name, locale_str) else (name, None)
         self.name: str = name
+        self._locale_name: Optional[locale_str] = locale
         self.value: ChoiceT = value
+        self.name_localizations: Dict[Locale, str] = MISSING
 
     def __eq__(self, o: object) -> bool:
         return isinstance(o, Choice) and self.name == o.name and self.value == o.value
@@ -441,11 +460,29 @@ class Choice(Generic[ChoiceT]):
                 f'invalid Choice value type given, expected int, str, or float but received {self.value.__class__!r}'
             )
 
-    def to_dict(self) -> ApplicationCommandOptionChoice:
-        return {
+    async def get_translated_payload(self, translator: Translator) -> Dict[str, Any]:
+        base = self.to_dict()
+        name_localizations: Dict[str, str] = {}
+        context = TranslationContext(location=TranslationContextLocation.choice_name, data=self)
+        if self._locale_name:
+            for locale in Locale:
+                translation = await translator._checked_translate(self._locale_name, locale, context)
+                if translation is not None:
+                    name_localizations[locale.value] = translation
+
+        if name_localizations:
+            base['name_localizations'] = name_localizations
+
+        return base
+
+    def to_dict(self) -> Dict[str, Any]:
+        base = {
             'name': self.name,
             'value': self.value,
         }
+        if self.name_localizations is not MISSING:
+            base['name_localizations'] = {str(k): v for k, v in self.name_localizations.items()}
+        return base
 
 
 class AppCommandChannel(Hashable):
@@ -744,6 +781,10 @@ class Argument:
         The name of the argument.
     description: :class:`str`
         The description of the argument.
+    name_localizations: Dict[:class:`~discord.Locale`, :class:`str`]
+        The localised names of the argument. Used for display purposes.
+    description_localizations: Dict[:class:`~discord.Locale`, :class:`str`]
+        The localised descriptions of the argument. Used for display purposes.
     required: :class:`bool`
         Whether the argument is required.
     choices: List[:class:`Choice`]
@@ -768,6 +809,8 @@ class Argument:
         'type',
         'name',
         'description',
+        'name_localizations',
+        'description_localizations',
         'required',
         'choices',
         'channel_types',
@@ -804,6 +847,8 @@ class Argument:
         self.choices: List[Choice[Union[int, float, str]]] = [
             Choice(name=d['name'], value=d['value']) for d in data.get('choices', [])
         ]
+        self.name_localizations: Dict[Locale, str] = _to_locale_dict(data.get('name_localizations') or {})
+        self.description_localizations: Dict[Locale, str] = _to_locale_dict(data.get('description_localizations') or {})
 
     def to_dict(self) -> ApplicationCommandOption:
         return {
@@ -819,6 +864,8 @@ class Argument:
             'max_length': self.max_length,
             'autocomplete': self.autocomplete,
             'options': [],
+            'name_localizations': {str(k): v for k, v in self.name_localizations.items()},
+            'description_localizations': {str(k): v for k, v in self.description_localizations.items()},
         }  # type: ignore # Type checker does not understand this literal.
 
 
@@ -835,6 +882,10 @@ class AppCommandGroup:
         The name of the subcommand.
     description: :class:`str`
         The description of the subcommand.
+    name_localizations: Dict[:class:`~discord.Locale`, :class:`str`]
+        The localised names of the subcommand. Used for display purposes.
+    description_localizations: Dict[:class:`~discord.Locale`, :class:`str`]
+        The localised descriptions of the subcommand. Used for display purposes.
     options: List[Union[:class:`Argument`, :class:`AppCommandGroup`]]
         A list of options.
     parent: Union[:class:`AppCommand`, :class:`AppCommandGroup`]
@@ -845,6 +896,8 @@ class AppCommandGroup:
         'type',
         'name',
         'description',
+        'name_localizations',
+        'description_localizations',
         'options',
         'parent',
         '_state',
@@ -893,6 +946,8 @@ class AppCommandGroup:
         self.options: List[Union[Argument, AppCommandGroup]] = [
             app_command_option_factory(data=d, parent=self, state=self._state) for d in data.get('options', [])
         ]
+        self.name_localizations: Dict[Locale, str] = _to_locale_dict(data.get('name_localizations') or {})
+        self.description_localizations: Dict[Locale, str] = _to_locale_dict(data.get('description_localizations') or {})
 
     def to_dict(self) -> 'ApplicationCommandOption':
         return {
@@ -900,6 +955,8 @@ class AppCommandGroup:
             'type': self.type.value,
             'description': self.description,
             'options': [arg.to_dict() for arg in self.options],
+            'name_localizations': {str(k): v for k, v in self.name_localizations.items()},
+            'description_localizations': {str(k): v for k, v in self.description_localizations.items()},
         }  # type: ignore # Type checker does not understand this literal.
 
 
@@ -935,9 +992,11 @@ class AppCommandPermissions:
         self.permission: bool = data['permission']
 
         _object = None
+        _type = MISSING
 
         if self.type is AppCommandPermissionType.user:
             _object = guild.get_member(self.id) or self._state.get_user(self.id)
+            _type = Member
         elif self.type is AppCommandPermissionType.channel:
             if self.id == (guild.id - 1):
                 _object = AllChannels(guild)
@@ -945,9 +1004,10 @@ class AppCommandPermissions:
                 _object = guild.get_channel(self.id)
         elif self.type is AppCommandPermissionType.role:
             _object = guild.get_role(self.id)
+            _type = Role
 
         if _object is None:
-            _object = Object(id=self.id)
+            _object = Object(id=self.id, type=_type)
 
         self.target: Union[Object, User, Member, Role, AllChannels, GuildChannel] = _object
 
