@@ -812,7 +812,7 @@ class DiscordVoiceWebSocket:
         self._close_code: Optional[int] = None
         self.secret_key: Optional[str] = None
         if hook:
-            self._hook = hook  # type: ignore # type-checker doesn't like overriding methods
+            self._hook = hook
 
     async def _hook(self, *args: Any) -> None:
         pass
